@@ -22,11 +22,14 @@
 # define TARGET_RISCV_ATTRIBUTE 1
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ARCH
-# define TARGET_RISCV_DEFAULT_ARCH rv64imafdc_zicsr_zifencei
+# define TARGET_RISCV_DEFAULT_ARCH rv64gc
 #endif
 #ifndef TARGET_RISCV_DEFAULT_ABI
 # define TARGET_RISCV_DEFAULT_ABI lp64d
 #endif
+#ifndef TARGET_DEFAULT_CMODEL
+# define TARGET_DEFAULT_CMODEL CM_MEDLOW
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
